@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -41,11 +41,19 @@ void create<Header>(nb::module_& m) {
     .value(PY_ENUM(Header::CPU_TYPE::X86_64))
     .value(PY_ENUM(Header::CPU_TYPE::MIPS))
     .value(PY_ENUM(Header::CPU_TYPE::MC98000))
+    .value(PY_ENUM(Header::CPU_TYPE::HPPA))
     .value(PY_ENUM(Header::CPU_TYPE::ARM))
     .value(PY_ENUM(Header::CPU_TYPE::ARM64))
+    .value(PY_ENUM(Header::CPU_TYPE::MC88000))
     .value(PY_ENUM(Header::CPU_TYPE::SPARC))
+    .value(PY_ENUM(Header::CPU_TYPE::I860))
+    .value(PY_ENUM(Header::CPU_TYPE::ALPHA))
     .value(PY_ENUM(Header::CPU_TYPE::POWERPC))
     .value(PY_ENUM(Header::CPU_TYPE::POWERPC64))
+    .value(PY_ENUM(Header::CPU_TYPE::APPLE_GPU))
+    .value(PY_ENUM(Header::CPU_TYPE::AMD_GPU))
+    .value(PY_ENUM(Header::CPU_TYPE::INTEL_GPU))
+    .value(PY_ENUM(Header::CPU_TYPE::AIR64))
   #undef PY_ENUM
   ;
 
@@ -63,6 +71,9 @@ void create<Header>(nb::module_& m) {
     .value(PY_ENUM(Header::FILE_TYPE::DYLIB_STUB))
     .value(PY_ENUM(Header::FILE_TYPE::DSYM))
     .value(PY_ENUM(Header::FILE_TYPE::KEXT_BUNDLE))
+    .value(PY_ENUM(Header::FILE_TYPE::FILESET))
+    .value(PY_ENUM(Header::FILE_TYPE::GPU_EXECUTE))
+    .value(PY_ENUM(Header::FILE_TYPE::GPU_DYLIB))
   #undef PY_ENUM
   ;
 
@@ -94,6 +105,10 @@ void create<Header>(nb::module_& m) {
     .value(PY_ENUM(Header::FLAGS::HAS_TLV_DESCRIPTORS))
     .value(PY_ENUM(Header::FLAGS::NO_HEAP_EXECUTION))
     .value(PY_ENUM(Header::FLAGS::APP_EXTENSION_SAFE))
+    .value(PY_ENUM(Header::FLAGS::NLIST_OUTOFSYNC_WITH_DYLDINFO))
+    .value(PY_ENUM(Header::FLAGS::SIM_SUPPORT))
+    .value(PY_ENUM(Header::FLAGS::IMPLICIT_PAGEZERO))
+    .value(PY_ENUM(Header::FLAGS::DYLIB_IN_CACHE))
   #undef PY_ENUM
   ;
 
@@ -151,6 +166,12 @@ void create<Header>(nb::module_& m) {
         &Header::flags_list,
         "" RST_CLASS_REF(lief.MachO.Header.FLAGS) " as a list"_doc)
 
+    .def_prop_ro("is_32bit", &Header::is_32bit,
+                 R"doc(True is the binary is 32-bits)doc"_doc)
+
+    .def_prop_ro("is_64bit", &Header::is_64bit,
+                 R"doc(True is the binary is 64-bits)doc"_doc)
+
     .def("add",
         nb::overload_cast<Header::FLAGS>(&Header::add),
         "Add the given " RST_CLASS_REF(lief.MachO.Header.FLAGS) ""_doc,
