@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 #include <string>
 #include <sstream>
 #include <nanobind/stl/string.h>
+#include "nanobind/extra/stl/lief_span.h"
 
 #include "enums_wrapper.hpp"
 #include "LIEF/PE/DataDirectory.hpp"
@@ -70,6 +71,9 @@ void create<DataDirectory>(nb::module_& m) {
         "" RST_CLASS_REF(lief.PE.Section) " associated with the current data directory or None if not linked"_doc,
         nb::rv_policy::reference_internal)
 
+    .def_prop_ro("content", nb::overload_cast<>(&DataDirectory::content, nb::const_),
+        "Raw content (bytes) referenced by this data directory"_doc)
+
     .def_prop_ro("type",
         &DataDirectory::type,
         "Type (" RST_CLASS_REF(lief.PE.DataDirectory.TYPES) ") of the current data directory"_doc,
