@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -44,7 +44,7 @@ void create<TLS>(nb::module_& m) {
         nb::overload_cast<>(&TLS::callbacks, nb::const_),
         nb::overload_cast<std::vector<uint64_t>>(&TLS::callbacks),
         R"delim(
-        List of the callback associated with the current TLS.
+        List of the callbacks associated with the current TLS.
 
         These functions are called before any other functions.
         )delim"_doc)
@@ -126,6 +126,11 @@ void create<TLS>(nb::module_& m) {
         "" RST_CLASS_REF(lief.PE.Section) " associated with the TLS object (or None if not linked)"_doc,
         nb::rv_policy::reference_internal)
 
+    .def("add_callback", &TLS::add_callback,
+         "Add a new TLS callback"_doc,
+         "addr"_a,
+         nb::rv_policy::reference_internal)
+
     LIEF_COPYABLE(TLS)
     LIEF_DEFAULT_STR(TLS);
 }
