@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -28,39 +28,50 @@ FMT_FORMATTER(LIEF::PE::RelocationEntry::BASE_TYPES, LIEF::PE::to_string);
 namespace LIEF {
 namespace PE {
 
-RelocationEntry::RelocationEntry(const RelocationEntry& other) :
-  LIEF::Relocation{other},
-  position_{other.position_},
-  type_{other.type_},
-  arch_{other.arch_},
-  relocation_{nullptr}
-{}
-
-RelocationEntry::RelocationEntry(uint16_t data, Header::MACHINE_TYPES arch) :
-  arch_(arch)
+RelocationEntry::BASE_TYPES
+  RelocationEntry::type_from_data(Header::MACHINE_TYPES arch, uint16_t data)
 {
-  this->data(data);
-}
+  uint8_t raw_type = get_type(data);
+  // Discriminate the type based on the the provided architecture
+  // for the values that depend on the arch.
+  if (raw_type == 5) {
+    if (Header::is_mips(arch)) {
+      return BASE_TYPES::MIPS_JMPADDR;
+    }
 
-void RelocationEntry::swap(RelocationEntry& other) {
-  LIEF::Relocation::swap(other);
-  std::swap(position_,   other.position_);
-  std::swap(type_,       other.type_);
-  std::swap(relocation_, other.relocation_);
-  std::swap(arch_,       other.arch_);
-}
+    if (Header::is_arm(arch)) {
+      return BASE_TYPES::ARM_MOV32;
+    }
 
+    if (Header::is_riscv(arch)) {
+      return BASE_TYPES::RISCV_HI20;
+    }
 
-uint16_t RelocationEntry::data() const {
-  auto raw_type = uint8_t(uint32_t(type_) & 0xFF);
-  return (uint16_t(raw_type) << 12 | uint16_t(position_));
-}
+    return BASE_TYPES::UNKNOWN;
+  }
 
-void RelocationEntry::data(uint16_t data) {
-  position_ = static_cast<uint16_t>(data & 0x0FFF);
-  auto raw_type = uint8_t(data >> 12);
-  // TODO(romain): Support arch-dependent types (ARM_MOV32A, RISCV_LOW12I, ...)
-  type_ = BASE_TYPES(raw_type);
+  if (raw_type == 7) {
+    if (Header::is_thumb(arch)) {
+      return BASE_TYPES::THUMB_MOV32;
+    }
+
+    if (Header::is_riscv(arch)) {
+      return BASE_TYPES::RISCV_LOW12I;
+    }
+
+    return BASE_TYPES::UNKNOWN;
+  }
+
+  if (raw_type == 8) {
+    if (Header::is_riscv(arch)) {
+      return BASE_TYPES::RISCV_LOW12S;
+    }
+    if (Header::is_loonarch(arch)) {
+      return BASE_TYPES::LOONARCH_MARK_LA;
+    }
+  }
+
+  return BASE_TYPES(raw_type);
 }
 
 uint64_t RelocationEntry::address() const {
@@ -71,8 +82,24 @@ uint64_t RelocationEntry::address() const {
   return position();
 }
 
-void RelocationEntry::address(uint64_t /*address*/) {
-  LIEF_WARN("Setting address of a PE relocation is not implemented!");
+void RelocationEntry::address(uint64_t address) {
+  if (relocation_ == nullptr) {
+    LIEF_ERR("parent relocation is not set");
+    return;
+  }
+  int32_t delta = address - relocation_->virtual_address();
+  if (delta < 0) {
+    LIEF_ERR("Invalid address: 0x{:04x} (base address=0x{:04x})",
+             address, relocation_->virtual_address());
+    return;
+  }
+
+  if (delta > MAX_ADDR) {
+    LIEF_ERR("0x{:04x} does not fit in a 12-bit encoding");
+    return;
+  }
+
+  position_ = delta;
 }
 
 size_t RelocationEntry::size() const {
@@ -80,24 +107,17 @@ size_t RelocationEntry::size() const {
     case BASE_TYPES::LOW:
     case BASE_TYPES::HIGH:
     case BASE_TYPES::HIGHADJ:
-      {
-        return 16;
-      }
+      return 16;
 
     case BASE_TYPES::HIGHLOW: // Addr += delta
-      {
-        return 32;
-      }
+      return 32;
 
     case BASE_TYPES::DIR64: // Addr += delta
-      {
-        return 64;
-      }
+      return 64;
+
     case BASE_TYPES::ABS:
     default:
-      {
-        return 0;
-      }
+      return 0;
   }
   return 0;
 }
@@ -111,7 +131,8 @@ void RelocationEntry::accept(Visitor& visitor) const {
 }
 
 std::ostream& operator<<(std::ostream& os, const RelocationEntry& entry) {
-  os << fmt::format("{}: 0x{:04x}", entry.type(), entry.position());
+  os << fmt::format("0x{:04x} {:14} 0x{:08x}",
+                    entry.data(), PE::to_string(entry.type()), entry.address());
   return os;
 }
 
@@ -125,17 +146,13 @@ const char* to_string(RelocationEntry::BASE_TYPES type) {
     ENTRY(HIGHLOW),
     ENTRY(HIGHADJ),
     ENTRY(MIPS_JMPADDR),
-    ENTRY(ARM_MOV32A),
     ENTRY(ARM_MOV32),
     ENTRY(RISCV_HI20),
     ENTRY(SECTION),
-    ENTRY(REL),
-    ENTRY(ARM_MOV32T),
     ENTRY(THUMB_MOV32),
     ENTRY(RISCV_LOW12I),
     ENTRY(RISCV_LOW12S),
     ENTRY(MIPS_JMPADDR16),
-    ENTRY(IA64_IMM64),
     ENTRY(DIR64),
     ENTRY(HIGH3ADJ),
   };
